Framework Documentation
=======================


There are two major components to constructing workflows,
building tools and assembling workflows.

.. toctree::
   :maxdepth: 1

   workflow
   commandtool
   tools/pythontool
   tools/codetool
   types

Features:

.. toctree::
   :maxdepth: 1

   expressions
   selectors
   scattering